@@ -139,6 +139,7 @@ EXTENSIONS = {
     'pxi': {'text', 'cython'},
     'py': {'text', 'python'},
     'pyi': {'text', 'pyi'},
+    'pyproj': {'text', 'xml', 'pyproj'},
     'pyx': {'text', 'cython'},
     'pyz': {'binary', 'pyz'},
     'pyzw': {'binary', 'pyz'},
@@ -184,6 +185,8 @@ EXTENSIONS = {
     'txsprofile': {'text', 'ini', 'txsprofile'},
     'txt': {'text', 'plain-text'},
     'v': {'text', 'verilog'},
+    'vbproj': {'text', 'xml', 'vbproj'},
+    'vcxproj': {'text', 'xml', 'vcxproj'},
     'vdx': {'text', 'vdx'},
     'vh': {'text', 'verilog'},
     'vhd': {'text', 'vhdl'},
